@@ -137,9 +137,15 @@ public class Analyzer<V extends Value> implements Opcodes {
     findSubroutines(method.maxLocals);
 
     // Initializes the data structures for the control flow analysis.
-    Frame<V> currentFrame = computeInitialFrame(owner, method);
-    merge(0, currentFrame, null);
-    init(owner, method);
+    Frame<V> currentFrame;
+    try {
+      currentFrame = computeInitialFrame(owner, method);
+      merge(0, currentFrame, null);
+      init(owner, method);
+    } catch (RuntimeException e) {
+      // DontCheck(IllegalCatch): can't be fixed, for backward compatibility.
+      throw new AnalyzerException(insnList.get(0), "Error at instruction 0: " + e.getMessage(), e);
+    }
 
     // Control flow analysis.
     while (numInstructionsToProcess > 0) {
@@ -168,7 +174,7 @@ public class Analyzer<V extends Value> implements Opcodes {
           if (insnNode instanceof JumpInsnNode) {
             JumpInsnNode jumpInsn = (JumpInsnNode) insnNode;
             if (insnOpcode != GOTO && insnOpcode != JSR) {
-              currentFrame.initJumpTarget(insnOpcode, /* target = */ null);
+              currentFrame.initJumpTarget(insnOpcode, /* target= */ null);
               merge(insnIndex + 1, currentFrame, subroutine);
               newControlFlowEdge(insnIndex, insnIndex + 1);
             }
@@ -257,9 +263,18 @@ public class Analyzer<V extends Value> implements Opcodes {
               catchType = Type.getObjectType(tryCatchBlock.type);
             }
             if (newControlFlowExceptionEdge(insnIndex, tryCatchBlock)) {
+              // Merge the frame *before* this instruction, with its stack cleared and an exception
+              // pushed, with the handler's frame.
               Frame<V> handler = newFrame(oldFrame);
+              V exceptionValue = interpreter.newExceptionValue(tryCatchBlock, handler, catchType);
               handler.clearStack();
-              handler.push(interpreter.newExceptionValue(tryCatchBlock, handler, catchType));
+              handler.push(exceptionValue);
+              merge(insnList.indexOf(tryCatchBlock.handler), handler, subroutine);
+              // Merge the frame *after* this instruction, with its stack cleared and an exception
+              // pushed, with the handler's frame.
+              handler = newFrame(currentFrame);
+              handler.clearStack();
+              handler.push(exceptionValue);
               merge(insnList.indexOf(tryCatchBlock.handler), handler, subroutine);
             }
           }
