@@ -30,6 +30,7 @@ package org.objectweb.asm;
 import static org.junit.jupiter.api.Assertions.assertDoesNotThrow;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertSame;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
@@ -68,6 +69,14 @@ class ClassVisitorTest extends AsmTest {
     assertEquals("Unsupported api 0", exception.getMessage());
   }
 
+  @Test
+  void testGetDelegate() {
+    ClassVisitor delegate = new ClassVisitor(Opcodes.ASM4) {};
+    ClassVisitor visitor = new ClassVisitor(Opcodes.ASM4, delegate) {};
+
+    assertSame(delegate, visitor.getDelegate());
+  }
+
   /**
    * Tests that classes are unchanged when transformed with a ClassReader -> class adapter ->
    * ClassWriter chain, where "class adapter" is a ClassVisitor which returns FieldVisitor,
