@@ -66,8 +66,8 @@ class ClassWriterTest extends AsmTest {
   /**
    * Tests that the non-static fields of ClassWriter are the expected ones. This test is designed to
    * fail each time new fields are added to ClassWriter, and serves as a reminder to update the
-   * field reset logic in {@link ClassWriter#replaceAsmInstructions()}, if needed, each time a new
-   * field is added.
+   * field reset logic in {@link ClassWriter#replaceAsmInstructions(byte[], boolean)}, if needed,
+   * each time a new field is added.
    */
   @Test
   void testInstanceFields() {
@@ -78,41 +78,40 @@ class ClassWriterTest extends AsmTest {
             .collect(toSet());
 
     Set<String> expectedFields =
-        new HashSet<String>(
-            Arrays.asList(
-                "flags",
-                "version",
-                "symbolTable",
-                "accessFlags",
-                "thisClass",
-                "superClass",
-                "interfaceCount",
-                "interfaces",
-                "firstField",
-                "lastField",
-                "firstMethod",
-                "lastMethod",
-                "numberOfInnerClasses",
-                "innerClasses",
-                "enclosingClassIndex",
-                "enclosingMethodIndex",
-                "signatureIndex",
-                "sourceFileIndex",
-                "debugExtension",
-                "lastRuntimeVisibleAnnotation",
-                "lastRuntimeInvisibleAnnotation",
-                "lastRuntimeVisibleTypeAnnotation",
-                "lastRuntimeInvisibleTypeAnnotation",
-                "moduleWriter",
-                "nestHostClassIndex",
-                "numberOfNestMemberClasses",
-                "nestMemberClasses",
-                "numberOfPermittedSubclasses",
-                "permittedSubclasses",
-                "firstRecordComponent",
-                "lastRecordComponent",
-                "firstAttribute",
-                "compute"));
+        Set.of(
+            "flags",
+            "version",
+            "symbolTable",
+            "accessFlags",
+            "thisClass",
+            "superClass",
+            "interfaceCount",
+            "interfaces",
+            "firstField",
+            "lastField",
+            "firstMethod",
+            "lastMethod",
+            "numberOfInnerClasses",
+            "innerClasses",
+            "enclosingClassIndex",
+            "enclosingMethodIndex",
+            "signatureIndex",
+            "sourceFileIndex",
+            "debugExtension",
+            "lastRuntimeVisibleAnnotation",
+            "lastRuntimeInvisibleAnnotation",
+            "lastRuntimeVisibleTypeAnnotation",
+            "lastRuntimeInvisibleTypeAnnotation",
+            "moduleWriter",
+            "nestHostClassIndex",
+            "numberOfNestMemberClasses",
+            "nestMemberClasses",
+            "numberOfPermittedSubclasses",
+            "permittedSubclasses",
+            "firstRecordComponent",
+            "lastRecordComponent",
+            "firstAttribute",
+            "compute");
     // IMPORTANT: if this fails, update the string list AND update the logic that resets the
     // ClassWriter fields in ClassWriter.toByteArray(), if needed (this logic is used to do a
     // ClassReader->ClassWriter round trip to remove the ASM specific instructions due to large
@@ -456,6 +455,64 @@ class ClassWriterTest extends AsmTest {
     assertTrue(new ClassFile(classFile).toString().contains("[[[[[[[[Ljava/lang/Number;"));
   }
 
+  @Test
+  void testToByteArray_manyFramesWithForwardLabelReferences() {
+    ClassWriter classWriter = new ClassWriter(0);
+    classWriter.visit(Opcodes.V1_7, Opcodes.ACC_PUBLIC, "A", null, "java/lang/Object", null);
+    MethodVisitor constructor =
+        classWriter.visitMethod(Opcodes.ACC_PUBLIC, "<init>", "()V", null, null);
+    constructor.visitCode();
+    constructor.visitVarInsn(Opcodes.ALOAD, 0);
+    constructor.visitMethodInsn(Opcodes.INVOKESPECIAL, "java/lang/Object", "<init>", "()V", false);
+    constructor.visitInsn(Opcodes.RETURN);
+    constructor.visitMaxs(1, 1);
+    constructor.visitEnd();
+    MethodVisitor methodVisitor =
+        classWriter.visitMethod(Opcodes.ACC_STATIC, "m", "()V", null, null);
+    methodVisitor.visitCode();
+    Label label0 = new Label();
+    methodVisitor.visitJumpInsn(Opcodes.GOTO, label0);
+    Label label1 = new Label();
+    methodVisitor.visitLabel(label1);
+    Label[] newLabels = new Label[24];
+    for (int i = 0; i < newLabels.length; ++i) {
+      newLabels[i] = new Label();
+    }
+    methodVisitor.visitFrame(Opcodes.F_NEW, newLabels.length, newLabels, 0, null);
+    for (int i = 0; i < newLabels.length; ++i) {
+      methodVisitor.visitVarInsn(Opcodes.ALOAD, i);
+      methodVisitor.visitMethodInsn(Opcodes.INVOKESPECIAL, "A", "<init>", "()V", false);
+    }
+    Label label2 = new Label();
+    methodVisitor.visitJumpInsn(Opcodes.GOTO, label2);
+    methodVisitor.visitLabel(label0);
+    Object[] topTypes = new Object[newLabels.length];
+    for (int i = 0; i < topTypes.length; ++i) {
+      topTypes[i] = Opcodes.TOP;
+    }
+    methodVisitor.visitFrame(Opcodes.F_NEW, topTypes.length, topTypes, 0, null);
+    for (int i = 0; i < newLabels.length; ++i) {
+      methodVisitor.visitLabel(newLabels[i]);
+      methodVisitor.visitTypeInsn(Opcodes.NEW, "A");
+      methodVisitor.visitVarInsn(Opcodes.ASTORE, i);
+    }
+    methodVisitor.visitJumpInsn(Opcodes.GOTO, label1);
+    methodVisitor.visitLabel(label2);
+    String[] newTypes = new String[newLabels.length];
+    for (int i = 0; i < newTypes.length; ++i) {
+      newTypes[i] = "A";
+    }
+    methodVisitor.visitFrame(Opcodes.F_NEW, newTypes.length, newTypes, 0, null);
+    methodVisitor.visitInsn(Opcodes.RETURN);
+    methodVisitor.visitMaxs(1, newLabels.length);
+    methodVisitor.visitEnd();
+    classWriter.visitEnd();
+
+    byte[] classFile = classWriter.toByteArray();
+
+    assertDoesNotThrow(() -> new ClassFile(classFile).newInstance());
+  }
+
   @Test
   void testGetCommonSuperClass() {
     ClassWriter classWriter = new ClassWriter(0);
